@@ -40,6 +40,7 @@ OC.L10N.register(
     "Delete file" : "Datei löschen",
     "Delete folder" : "Ordner löschen",
     "Disconnect storage" : "Speicher trennen",
+    "Leave this share" : "Diese Freigabe verlassen",
     "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
     "Files" : "Dateien",
     "Details" : "Details",
@@ -100,10 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Dein Speicher ist beinahe voll ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
     "View in folder" : "In Ordner anzeigen",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
     "Path" : "Pfad",
     "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
     "Favorited" : "Favorisiert",
     "Favorite" : "Favorit",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Direktlink kopieren (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
     "New folder" : "Neuer Ordner",
     "Create new folder" : "Neuen Ordner erstellen",
     "Upload file" : "Datei hochladen",
@@ -124,6 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "Wiederhergestellt durch {user}",
     "Renamed by {user}" : "Umbenannt durch {user}",
     "Moved by {user}" : "Verschoben durch {user}",
+    "\"remote account\"" : "\"Entferntes Konto\"",
     "You created {file}" : "Du hast {file} erstellt",
     "You created an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} erstellt",
     "{user} created {file}" : "{user} hat {file} erstellt",
@@ -157,6 +161,8 @@ OC.L10N.register(
     "Reject" : "Ablehnen",
     "Incoming ownership transfer from {user}" : "Eingehende Besitzübertragung von {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Soll {path} angenommen werden?\n\nInfo: Der Übertragungsprozess nach der Annahme kann bis zu einer Stunde dauern.",
+    "Ownership transfer denied" : "Besitzübertragung verweigert",
+    "Your ownership transfer of {path} was denied by {user}." : "Die Eigentumsübertragung von {path} wurde von {user} abgelehnt.",
     "Ownership transfer failed" : "Besitzübertragung fehlgeschlagen",
     "Your ownership transfer of {path} to {user} failed." : "Die Besitzübertragung von {path} an {user} ist fehlgeschlagen.",
     "The ownership transfer of {path} from {user} failed." : "Die Übertragung von {path} ist fehlgeschlagen.",
@@ -164,7 +170,9 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Die Besitzübertragung von {path} an {user} wurde fertiggestellt.",
     "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
     "in %s" : "in %s",
+    "Transferred from %1$s on %2$s" : "Übertragen von %1$s auf %2$s",
     "File Management" : "Dateiverwaltung",
+    "Current directory path" : "Aktueller Verzeichnispfad",
     "Reload current directory" : "Aktuelles Verzeichnis neu laden",
     "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}“ wechseln",
     "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
@@ -172,11 +180,14 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
     "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" erfolgreich ausgeführt",
     "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
+    "Toggle selection for file \"{displayName}\"" : "Auswahl für die Datei \"{displayName}\" umschalten",
+    "Toggle selection for folder \"{displayName}\"" : "Auswahl für den Ordner \"{displayName}\" umschalten",
     "Rename file" : "Datei umbenennen",
     "File name" : "Dateiname",
     "Folder name" : "Ordnername",
     "This node is unavailable" : "Dieser Knoten ist nicht verfügbar.",
     "Download file {name}" : "Datei {name} herunterladen",
+    "Invalid file name" : "Ungültiger Dateiname",
     "\"{name}\" is not an allowed filetype." : "\"{name}\" ist kein zulässiger Dateityp.",
     "{newName} already exists." : "{newName} existiert bereits.",
     "\"{char}\" is not allowed inside a file name." : "\"{char}“ ist innerhalb eines Dateinamens nicht zulässig.",
@@ -187,8 +198,10 @@ OC.L10N.register(
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte wähle einen anderen Namen.",
     "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden.",
     "Total rows summary" : "Zusammenfassung aller Zeilen",
+    "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
     "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
+    "{count} selected" : "{count} ausgewählt",
     "List of files and folders." : "Liste der Dateien und Ordner",
     "Column headers with buttons are sortable." : "Spaltenüberschriften mit Schaltflächen sind sortierbar.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Diese Liste wird aus Performance-Gründen nicht vollständig angezeigt. Die Dateien werden angezeigt, wenn du durch die Liste navigierst.",
@@ -199,6 +212,7 @@ OC.L10N.register(
     "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
     "Your storage is full, files can not be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
     "Create" : "Erstellen",
+    "A file or folder with that name already exists." : "Eine Datei oder ein Ordner mit diesem Namen existiert bereits.",
     "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
     "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
     "Change" : "Ändern",
@@ -223,12 +237,18 @@ OC.L10N.register(
     "Shared" : "Geteilt",
     "Switch to list view" : "Zur Listenansicht wechseln",
     "Switch to grid view" : "Zur Rasteransicht wechseln",
+    "Upload was cancelled by user" : "Das Hochladen wurde vom Benutzer abgebrochen.",
     "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
+    "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
     "Unknown error during upload" : "unbekannte Fehler während des Hochladens",
     "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
     "Files settings" : "Dateien-Einstellungen",
     "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Du hast keine Berechtigung, um sie anzuzeigen. Bitte den Absender, die Datei zu teilen.",
+    "Your files" : "Deine Dateien",
+    "Open in files" : "In Dateien öffnen",
     "Sort favorites first" : "Favoriten zuerst sortieren",
+    "Sort folders before files" : "Ordner vor Dateien sortieren",
     "Show hidden files" : "Versteckte Dateien anzeigen",
     "Crop image previews" : "Bildvorschauen zuschneiden",
     "Enable the grid view" : "Rasteransicht aktivieren",
@@ -248,16 +268,29 @@ OC.L10N.register(
     "Blank" : "Leer",
     "Unable to create new file from template" : "Neue Datei konnte nicht aus Vorlage erstellt werden",
     "Delete permanently" : "Endgültig löschen",
+    "Delete and unshare" : "Löschen und nicht mehr teilen",
+    "Leave these shares" : "Diese Freigaben verlassen",
+    "Disconnect storages" : "Speicher trennen",
     "Delete files" : "Dateien löschen",
+    "Delete folders" : "Ordner löschen",
+    "You are about to delete {count} items." : "Du bist dabei, {count} Elemente zu löschen.",
+    "Confirm deletion" : "Löschen bestätigen",
     "Cancel" : "Abbrechen",
+    "Deletion cancelled" : "Löschen abgebrochen",
     "Destination is not a folder" : "Ziel ist kein Ordner",
     "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden.",
+    "(copy)" : "(kopieren)",
+    "(copy %n)" : "(%n kopieren)",
+    "Move cancelled" : "Verschieben abgebrochen",
     "A file or folder with that name already exists in this folder" : "In diesem Ordner ist bereits eine Datei oder ein Ordner mit diesem Namen vorhanden",
+    "The files are locked" : "Die Dateien sind gesperrt",
     "The file does not exist anymore" : "Die Datei existiert nicht mehr",
+    "Choose destination" : "Ziel wählen",
     "Copy to {target}" : "Nach {target} kopieren",
     "Move to {target}" : "Nach {target} verschieben",
     "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
+    "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
     "Open folder {displayName}" : "Ordner {displayName} öffnen",
     "Open in Files" : "In App \"Dateien\" öffnen",
     "Open details" : "Details öffnen",
@@ -266,8 +299,22 @@ OC.L10N.register(
     "Unable to initialize the templates directory" : "Der Vorlagenordner konnte nicht initialisiert werden",
     "Create new templates folder" : "Neuen Vorlagenordner erstellen",
     "Templates" : "Vorlagen",
+    "New template folder" : "Neuer Vorlagenordner",
+    "In folder" : "Im Ordner",
+    "Search in folder: {folder}" : "Im Ordner suchen: {folder}",
     "One of the dropped files could not be processed" : "Eine der abgelegten Dateien konnte nicht verarbeitet werden",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Dein Browser unterstützt die Dateisystem-API nicht. Verzeichnisse werden nicht hochgeladen.",
+    "No files to upload" : "Keine Dateien zum Hochladen",
+    "Unable to create the directory {directory}" : "Der Ordner {directory} konnte nicht erstellt werden",
+    "Some files could not be uploaded" : "Einige Dateien konnten nicht hochgeladen werden.",
+    "Files uploaded successfully" : "Dateien hochgeladen",
+    "No files to process" : "Keine Dateien zum Verarbeiten",
+    "Some files could not be copied" : "Einige Dateien konnten nicht kopiert werden",
     "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden.",
+    "Files copied successfully" : "Dateien kopiert",
+    "Files moved successfully" : "Dateien verschoben",
+    "Conflicts resolution skipped" : "Konfliktelösung übersprungen",
+    "Upload cancelled" : "Hochladen abgebrochen",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} Ordner","{folderCount} Ordner"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} Datei","{fileCount} Dateien"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
@@ -278,6 +325,10 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die als Favoriten markiert werden, erscheinen hier",
     "All files" : "Alle Dateien",
     "List of your files and folders." : "Liste deiner Dateien und Ordner",
+    "Personal Files" : "Persönliche Dateien",
+    "List of your files and folders that are not shared." : "Liste deiner Dateien und Ordner, die nicht geteilt wurden.",
+    "No personal files found" : "Keine persönlichen Dateien gefunden",
+    "Files that are not shared will show up here." : "Dateien, die nicht geteilt wurden, werden hier angezeigt.",
     "List of recently modified files and folders." : "Liste der zuletzt geänderten Dateien und Ordner",
     "No recently modified files" : "Keine kürzlich geänderten Dateien",
     "Files and folders you recently modified will show up here." : "Die von dir kürzlich geänderten Dateien und Ordner werden hier angezeigt.",
