@@ -8,7 +8,6 @@ OC.L10N.register(
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "%1$s aplikazioa ez dago edo zerbitzari honekiko bertsio bateraezina du. Mesedez egiaztatu aplikazioen karpeta.",
     "Sample configuration detected" : "Adibide-ezarpena detektatua",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Adibide-ezarpena kopiatu dela detektatu da. Honek zure instalazioa apur dezake eta ez da onartzen. Irakurri dokumentazioa config.php fitxategia aldatu aurretik.",
-    "404" : "404",
     "The page could not be found on the server." : "Orria ez da zerbitzarian aurkitu.",
     "%s email verification" : "%sposta elektronikoaren egiaztapena",
     "Email verification" : "Posta elektronikoaren egiaztapena",
@@ -24,6 +23,7 @@ OC.L10N.register(
     "Enterprise bundle" : "Enpresa multzoa",
     "Groupware bundle" : "Talderanerako multzoa",
     "Hub bundle" : "Hub sorta",
+    "Public sector bundle" : "Sektore publikoko sorta",
     "Social sharing bundle" : "Partekatze sozial multzoa",
     "PHP %s or higher is required." : "PHP %s edo berriagoa behar da.",
     "PHP with a version lower than %s is required." : "PHPren bertsioa %s baino txikiagoa izan behar da.",
@@ -37,9 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Hurrengo plataformak onartzen dira: %s",
     "Server version %s or higher is required." : "Zerbitzariaren %s bertsioa edo berriagoa behar da.",
     "Server version %s or lower is required." : "Zerbitzariaren %s bertsioa edo zaharragoa behar da.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako erabiltzailea administratzailea, azpi-administratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
-    "Logged in user must be an admin or sub admin" : "Saioa hasitako erabiltzailea administratzaile edo azpi-administratzailea izan behar du",
-    "Logged in user must be an admin" : "Saioa hasitako erabiltzailea administratzailea izan behar da",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako kontua administratzailea, azpi-administratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
+    "Logged in account must be an admin or sub admin" : "Saioa hasitako kontua administratzaile edo azpi-administratzailea izan behar du",
+    "Logged in account must be an admin" : "Saioa hasitako kontua administratzailea izan behar du",
     "Wiping of device %s has started" : "%s gailuaren garbiketa hasi da",
     "Wiping of device »%s« has started" : "»%s« gailuaren garbiketa hasi da",
     "»%s« started remote wipe" : "»%s«(e)k urruneko garbiketa hasi du",
@@ -80,6 +80,8 @@ OC.L10N.register(
     "seconds ago" : "duela segundo batzuk",
     "Empty file" : "Fitxategi hutsa",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s IDa duen modulua ez da existitzen. Gaitu zure aplikazioen ezarpenetan edo jarri harremanetan administratzailearekin.",
+    "Dot files are not allowed" : "Dot fitxategiak ez dira onartzen",
+    "Invalid filename extension \"%1$s\"" : "\"%1$s\" fitxategi luzapen baliogabea",
     "File already exists" : "Badago izen bereko fitxategi bat",
     "Invalid path" : "Bide-izen baliogabea",
     "Failed to create file from template" : "Fitxategi berria txantiloitik sortzeak huts egin du",
@@ -87,20 +89,19 @@ OC.L10N.register(
     "File name is a reserved word" : "Fitxategi izena hitz erreserbatua da",
     "File name contains at least one invalid character" : "Fitxategi izenak karaktere baliogabe bat du gutxienez ",
     "File name is too long" : "Fitxategi-izena luzeegia da",
-    "Dot files are not allowed" : "Dot fitxategiak ez dira onartzen",
     "Empty filename is not allowed" : "Fitxategiaren izena ezin da hutsa izan",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "«%s» aplikazioa ezin da instalatu appinfo fitxategia ezin delako irakurri.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" aplikazioa ezin da instalatu ez delako zerbitzariaren bertsio honekin bateragarria.",
     "__language_name__" : "Euskara",
     "This is an automatically sent email, please do not reply." : "Hau automatikoki bidalitako mezua da, ez erantzun mesedez.",
-    "Help" : "Laguntza",
+    "Help & privacy" : "Laguntza eta pribatutasuna",
     "Appearance and accessibility" : "Itxura eta irisgarritasuna",
     "Apps" : "Aplikazioak",
     "Personal settings" : "Ezarpen pertsonalak",
     "Administration settings" : "Administrazio ezarpenak",
     "Settings" : "Ezarpenak",
     "Log out" : "Amaitu saioa",
-    "Users" : "Erabiltzaileak",
+    "Accounts" : "Kontuak",
     "Email" : "Posta elektronikoa",
     "Mail %s" : "Idatzi %s(r)i",
     "Fediverse" : "Fedibertsoa",
@@ -118,32 +119,35 @@ OC.L10N.register(
     "Headline" : "Izenburua",
     "Organisation" : "Erakundea",
     "Role" : "Zeregina",
-    "Unknown user" : "Erabiltzaile ezezaguna",
+    "Unknown account" : "Kontu ezezaguna",
     "Additional settings" : "Ezarpen gehiago",
-    "Enter the database username and name for %s" : "%s sartu datu-basearen izena eta erabiltzaile-izena",
-    "Enter the database username for %s" : "Sartu %s(r)en datu-base erabiltzaile-izena",
+    "Enter the database Login and name for %s" : "Sartu datu-basearen saioa eta izena %s(r)entzako",
+    "Enter the database Login for %s" : "Sartu %s(r)en datu-base saioa",
     "Enter the database name for %s" : "Sartu %s(r)en datu-base izena",
     "You cannot use dots in the database name %s" : "Ezin duzu punturik erabili %s datu-base izenean",
-    "MySQL username and/or password not valid" : "MySQL erabiltzaile-izen edota pasahitza baliogabea",
+    "MySQL Login and/or password not valid" : "MySQL saio edota pasahitza baliogabea",
     "You need to enter details of an existing account." : "Existitzen den kontu baten xehetasunak sartu behar dituzu.",
     "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
-    "Oracle username and/or password not valid" : "Oracle erabiltzaile edo/eta pasahitza ez dira baliozkoak.",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzailea edo/eta pasahitza ez dira baliozkoak.",
+    "Oracle Login and/or password not valid" : "Oracle saio edota pasahitza baliogabea",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL saio edota pasahitza baliogabea",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ez da onartzen eta %s gaizki ibiliko da plataforma honetan. Erabiltzekotan, zure ardurapean.",
     "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez kontsideratu GNU/Linux zerbitzari bat erabiltzea.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Badirudi %s instantzia hau 32 biteko PHP ingurune bat exekutatzen ari dela eta open_basedir aldagaia php.ini fitxategian konfiguratu dela. Honek arazoak sortuko ditu 4 GB baino gehiagoko fitxategiekin eta ez da batere gomendagarria.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez kendu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
-    "Set an admin username." : "Ezarri administraziorako erabiltzaile izena.",
+    "Set an admin Login." : "Ezarri administraziorako saioa.",
     "Set an admin password." : "Ezarri administraziorako pasahitza.",
     "Cannot create or write into the data directory %s" : "Ezin da sortu edo idatzi %s datu-direktorioan ",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s partekatze motorrak OCP\\Share_Backend interfazea inplementatu behar du ",
     "Sharing backend %s not found" : "Ez da %s partekatze motorra aurkitu",
     "Sharing backend for %s not found" : "Ez da %s(e)rako partekatze motorrik aurkitu",
+    "%1$s shared »%2$s« with you" : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
+    "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin.",
+    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
+    "Open »%s«" : "Ireki »%s«",
+    "%1$s via %2$s" : "%2$s bidez, %1$s",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du",
     "»%s« added a note to a file shared with you" : "»%s« erabiltzaileak ohar bat gehitu du partekatu dizun fitxategi batean",
-    "Open »%s«" : "Ireki »%s«",
-    "%1$s via %2$s" : "%2$s bidez, %1$s",
     "You are not allowed to share %s" : "Ez duzu %s partekatzeko baimenik",
     "Cannot increase permissions of %s" : "Ezin dira %s(r)en baimenak handitu",
     "Files cannot be shared with delete permissions" : "Fitxategiak ezin dira ezabatze baimenarekin partekatu",
@@ -151,13 +155,13 @@ OC.L10N.register(
     "Expiration date is in the past" : "Iraungitze-data iraganean dago",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri","Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri"],
     "Sharing is only allowed with group members" : "Taldeko kideekin bakarrik parteka daiteke",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s partekatzeak huts egin du dagoeneko %serabiltzailearekin partekatuta dagoelako",
-    "%1$s shared »%2$s« with you" : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
-    "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin.",
-    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
+    "Sharing %s failed, because this item is already shared with the account %s" : "%s partekatzeak huts egin du, dagoeneko %s kontuarekin partekatuta dagoelako",
     "The requested share does not exist anymore" : "Eskatutako partekatzea ez da existitzen dagoeneko",
+    "The requested share comes from a disabled user" : "Eskatutako partekatzea desgaitutako erabiltzaile batengatik dator",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Ezin izan da erabiltzailea sortu, erabiltzaile muga gainditu delako. Egiaztatu zure jakinarazpenak gehiago jakiteko.",
     "Could not find category \"%s\"" : "Ezin da \"%s\" kategoria aurkitu",
+    "Input text" : "Sartu testua",
+    "The input text" : "Sarrerako testua",
     "Sunday" : "Igandea",
     "Monday" : "Astelehena",
     "Tuesday" : "Asteartea",
@@ -204,14 +208,14 @@ OC.L10N.register(
     "Nov." : "Aza.",
     "Dec." : "Abe.",
     "A valid password must be provided" : "Baliozko pasahitza eman behar da",
-    "The username is already being used" : "Erabiltzaile izena dagoeneko erabilita dago",
-    "Could not create user" : "Ezin izan da erabiltzailea sortu",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Honako karaktereak bakarrik onartzen dira erabiltzaile izenetan: \"a-z\", \"A-Z\", \"0-9\", zuriuneak eta \"_.@-'\"",
-    "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
-    "Username contains whitespace at the beginning or at the end" : "Erabiltzaile-izenak zuriuneren bat du hasieran edo amaieran",
-    "Username must not consist of dots only" : "Erabiltzaile-izena ezin da puntuz osatuta soilik egon",
-    "Username is invalid because files already exist for this user" : "Erabiltzaile-izena ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
-    "User disabled" : "Erabiltzaile desgaituta",
+    "The Login is already being used" : "Saioa dagoeneko erabilita dago",
+    "Could not create account" : "Ezin izan da kontua sortu",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Honako karaktereak bakarrik onartzen dira saioan: \"a-z\", \"A-Z\", \"0-9\", zuriuneak eta \"_.@-'\"",
+    "A valid Login must be provided" : "Baliozko saioa eman behar da",
+    "Login contains whitespace at the beginning or at the end" : "Saioak zuriuneren bat du hasieran edo amaieran",
+    "Login must not consist of dots only" : "Saioa ezin da puntuz osatuta soilik egon",
+    "Login is invalid because files already exist for this user" : "Saioa ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
+    "Account disabled" : "Kontua desgaituta",
     "Login canceled by app" : "Aplikazioak saioa bertan behera utzi du",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" aplikazioa ezin da instalatu, menpekotasun hauek betetzen ez direlako:%2$s",
     "a safe home for all your data" : "zure datu guztientzako toki segurua",
@@ -244,10 +248,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Mesedez eskatu zerbitzariaren administratzaileari web zerbitzaria berrabiarazteko.",
     "The required %s config variable is not configured in the config.php file." : "Beharrezko %s config aldagaia ez dago konfiguratuta config.php fitxategian.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Mesedez, eskatu zure zerbitzari administratzaileari Nextclouden konfigurazioa egiaztatzeko.",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 behar da",
-    "Please upgrade your database version." : "Mesedez eguneratu zure datu-basearen bertsioa.",
-    "Your data directory is readable by other users." : "Zure datuen karpeta beste erabiltzaileek irakur dezakete.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
+    "Your data directory is readable by other people." : "Zure datuen karpeta beste pertsonek irakur dezakete.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Aldatu baimenak 0770ra beste pertsonak karpeta ikusi ezin izateko.",
     "Your data directory must be an absolute path." : "Zure datuen karpeta bide-izen absolutua izan behar da.",
     "Check the value of \"datadirectory\" in your configuration." : "Egiaztatu \"datadirectory\"-ren balioa zure konfigurazioan.",
     "Your data directory is invalid." : "Zure datuen karpeta baliogabea da.",
@@ -263,12 +265,106 @@ OC.L10N.register(
     "Storage connection error. %s" : "Biltegiratze-konexioaren errorea. %s",
     "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
     "Storage connection timeout. %s" : "Biltegiratze-konexioa denboraz kanpo geratu da. %s",
+    "Transcribe audio" : "Audioa transkribatu",
+    "Transcribe the things said in an audio" : "Audio batean esandako gauzak transkribatu",
+    "Audio input" : "Audio sarrera",
+    "The audio to transcribe" : "Transkribatzeko audioa",
+    "Transcription" : "Transkripzioa",
+    "The transcribed text" : "Transkribatutako testua",
+    "ContextWrite" : "ContextWrite",
+    "Writes text in a given style based on the provided source material." : "Testua estilo jakin batean idazten du, emandako iturri-materialean oinarrituta.",
+    "Writing style" : "Idazteko estiloa",
+    "Demonstrate a writing style that you would like to immitate" : "Erakutsi imitatu nahiko zenukeen idazteko estiloa",
+    "Source material" : "Jatorrizko materiala",
+    "The content that would like to be rewritten in the new writing style" : "Idazkera estilo berrian berridatzi nahi den edukia",
+    "Generated text" : "Sortutako testua",
+    "The generated text with content from the source material in the given style" : "Jatorri-materialaren edukiarekin emandako estiloan sortutako testua.",
+    "Emoji generator" : "Emojien sortzailea",
+    "Takes text and generates a representative emoji for it." : "Testua hartzen du eta emoji adierazgarri bat sortzen du.",
+    "The text to generate an emoji for" : "Emoji bat sortzeko testua",
+    "Generated emoji" : "Sortutako emojia",
+    "The generated emoji based on the input text" : "Sarrerako testuan oinarrituta sortutako emojia",
+    "Generate image" : "Sortu irudia",
+    "Generate an image from a text prompt" : "Sortu irudi bat testu-gonbita batetik",
+    "Prompt" : "Galdera",
+    "Describe the image you want to generate" : "Deskribatu sortu nahi duzun irudia",
+    "Number of images" : "Irudi kopurua",
+    "How many images to generate" : "Zenbat irudi sortu behar diren",
+    "Output images" : "Irteera irudiak",
+    "The generated images" : "Sortutako irudiak",
+    "Free text to text prompt" : "Testu librea mezuaren testura",
+    "Runs an arbitrary prompt through a language model that retuns a reply" : "Erantzun bat bueltatzen duen hizkuntza ereduaren zehar esaldi arbitrario bat exekutatzen du.",
+    "Describe a task that you want the assistant to do or ask a question" : "Deskribatu laguntzaileak egitea nahi duzun zeregina edo galdera bat egin",
+    "Generated reply" : "Sortutako erantzuna",
+    "The generated text from the assistant" : "Laguntzaileak sortutako testua",
+    "Chat" : "Chat",
+    "Chat with the assistant" : "Hitz egin txat bidez laguntzailarekin",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definitu elkarrizketan zehar txat laguntzaileak jarraitu beharko lituzkeen arau eta suposizioak.",
+    "Chat message" : "Txat mezua",
+    "Chat history" : "Txat historia",
+    "The history of chat messages before the current message, starting with a message by the user" : "Uneko mezuaren aurreko txat mezuen historia, erabiltzailearen mezu batetik hasita",
+    "Response message" : "Erantzun mezua",
+    "The generated response as part of the conversation" : "Sorturiko erantzuna, elkarrizketaren zati gisa",
+    "Formalize text" : "Formaldu testua",
+    "Takes a text and makes it sound more formal" : "Testu bat hartzen du eta doinu formalagoa ematen dio.",
+    "Write a text that you want the assistant to formalize" : "Idatz ezazu laguntzaileak formaltzea nahi duzun testu bat",
+    "Formalized text" : "Formaldutako testua",
+    "The formalized text" : "Formaldutako testua",
+    "Generate a headline" : "Sortu izenburu bat",
+    "Generates a possible headline for a text." : "Testu baten izenburu posiblea sortzen du.",
+    "Original text" : "Jatorrizko testua",
+    "The original text to generate a headline for" : "Izenburu bat sortzeko jatorrizko testua",
+    "The generated headline" : "Sortutako izenburua",
+    "Reformulate text" : "Birformulatu testua",
+    "Takes a text and reformulates it" : "Testu bat hartu eta birformulatu egiten du",
+    "Write a text that you want the assistant to reformulate" : "Idatz ezazu laguntzaileak birformulatzea nahi duzun testu bat",
+    "Reformulated text" : "Birformulatutako testua",
+    "The reformulated text, written by the assistant" : "Birformulaturiko testua, laguntzaileak idatzia",
+    "Simplify text" : "Sinpletu testua",
+    "Takes a text and simplifies it" : "Testu bat hartu eta sinpletu egiten du",
+    "Write a text that you want the assistant to simplify" : "Idatz ezazu laguntzaileak sinpletzea nahi duzun testu bat",
+    "Simplified text" : "Sinpletutako testua",
+    "The simplified text" : "Sinpletutako testua",
+    "Summarize" : "Laburtu",
+    "Summarizes a text" : "Laburtu testu bat",
+    "The original text to summarize" : "Laburtu beharreko jatorrizko testua",
+    "Summary" : "Laburpena",
+    "The generated summary" : "Sortutako laburpena",
+    "Extract topics" : "Atera gaiak",
+    "Extracts topics from a text and outputs them separated by commas" : "Gaiak ateratzen ditu testu batetik eta komaz banatuta erakusten ditu",
+    "The original text to extract topics from" : "Gaiak ateratzeko jatorrizko testua",
+    "Topics" : "Gaiak",
+    "The list of extracted topics" : "Ateratako gaien zerrenda",
     "Free prompt" : "Gonbita librea",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "%1$s aplikazioaren fitxategiak ez dira behar bezala ordezkatu. Ziurtatu zerbitzariarekin bateragarria den bertsioa dela.",
-    "Full name" : "Izen osoa",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Ezin izan da erabiltzailea sortu, erabiltzaile muga gainditu delako. Egiaztatu zure jakinarazpenak gehiago jakiteko.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Erabiltzaile-izenean karaktere hauek soilik erabil daitezke: \"a-z\", \"A-Z\", \"0-9\", eta \"_.@-'\"",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 bertsioa edo berriagoa behar da. Orain %s dago instalatuta.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Arazo hori konpontzeko, eguneratu zure libxml2 bertsioa eta berrabiarazi web zerbitzaria."
+    "Runs an arbitrary prompt through the language model." : "Hizkuntza ereduaren zehar esaldi arbitrario bat exekutatzen du.",
+    "Generate headline" : "Sortu izenburua",
+    "Summarizes text by reducing its length without losing key information." : "Testua laburtzen du bere luzera murrizten informazio baliotsua galdu gabe.",
+    "Extracts topics from a text and outputs them separated by commas." : "Gaiak ateratzen ditu testu batetik eta komaz banatuta erakusten ditu.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako erabiltzailea administratzailea, azpi-administratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
+    "Logged in user must be an admin or sub admin" : "Saioa hasitako erabiltzailea administratzaile edo azpi-administratzailea izan behar du",
+    "Logged in user must be an admin" : "Saioa hasitako erabiltzailea administratzailea izan behar da",
+    "Help" : "Laguntza",
+    "Users" : "Erabiltzaileak",
+    "Unknown user" : "Erabiltzaile ezezaguna",
+    "Enter the database username and name for %s" : "%s sartu datu-basearen izena eta erabiltzaile-izena",
+    "Enter the database username for %s" : "Sartu %s(r)en datu-base erabiltzaile-izena",
+    "MySQL username and/or password not valid" : "MySQL erabiltzaile-izen edota pasahitza baliogabea",
+    "Oracle username and/or password not valid" : "Oracle erabiltzaile edo/eta pasahitza ez dira baliozkoak.",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzailea edo/eta pasahitza ez dira baliozkoak.",
+    "Set an admin username." : "Ezarri administraziorako erabiltzaile izena.",
+    "Sharing %s failed, because this item is already shared with user %s" : "%s partekatzeak huts egin du dagoeneko %serabiltzailearekin partekatuta dagoelako",
+    "The username is already being used" : "Erabiltzaile izena dagoeneko erabilita dago",
+    "Could not create user" : "Ezin izan da erabiltzailea sortu",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Honako karaktereak bakarrik onartzen dira erabiltzaile izenetan: \"a-z\", \"A-Z\", \"0-9\", zuriuneak eta \"_.@-'\"",
+    "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
+    "Username contains whitespace at the beginning or at the end" : "Erabiltzaile-izenak zuriuneren bat du hasieran edo amaieran",
+    "Username must not consist of dots only" : "Erabiltzaile-izena ezin da puntuz osatuta soilik egon",
+    "Username is invalid because files already exist for this user" : "Erabiltzaile-izena ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
+    "User disabled" : "Erabiltzaile desgaituta",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 behar da",
+    "Please upgrade your database version." : "Mesedez eguneratu zure datu-basearen bertsioa.",
+    "Your data directory is readable by other users." : "Zure datuen karpeta beste erabiltzaileek irakur dezakete.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko."
 },
 "nplurals=2; plural=(n != 1);");
